Learn R Programming

gghdr (version 0.2.0)

lane2: Example dataframe for gghdr

Description

Example dataframe for gghdr

Usage

data(lane2)

Arguments

Format

This contains the 'lane2' data from the 'hdrcde' package and is used in the examples in README and vignettes.

The variables are as follows:

  • flow. a numeric vector giving the traffic flow in vehicles per lane per hour

  • speed. a numeric vector giving he speed in miles per hour